==> zio-aws-robomaker_3-5.17.130.5-sources.jar: zio/aws/robomaker/model/ListRobotApplicationsRequest.scala <==
package zio.aws.robomaker.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.robomaker.model.primitives.{
  MaxResults,
  PaginationToken,
  VersionQualifier
}
import scala.jdk.CollectionConverters.*
final case class ListRobotApplicationsRequest(
    versionQualifier: Option[VersionQualifier] = None,
    nextToken: Option[PaginationToken] = None,
    maxResults: Option[MaxResults] = None,
    filters: Option[Iterable[zio.aws.robomaker.model.Filter]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.ListRobotApplicationsRequest = {
    import ListRobotApplicationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.ListRobotApplicationsRequest
      .builder()
      .optionallyWith(
        versionQualifier.map(value =>
          VersionQualifier.unwrap(value): java.lang.String
        )
      )(_.versionQualifier)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .build()
  }
  def asReadOnly
      : zio.aws.robomaker.model.ListRobotApplicationsRequest.ReadOnly =
    zio.aws.robomaker.model.ListRobotApplicationsRequest.wrap(buildAwsValue())
}
object ListRobotApplicationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.robomaker.model.ListRobotApplicationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.ListRobotApplicationsRequest =
      zio.aws.robomaker.model.ListRobotApplicationsRequest(
        versionQualifier.map(value => value),
        nextToken.map(value => value),
        maxResults.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def versionQualifier: Option[VersionQualifier]
    def nextToken: Option[PaginationToken]
    def maxResults: Option[MaxResults]
    def filters: Option[List[zio.aws.robomaker.model.Filter.ReadOnly]]
    def getVersionQualifier: ZIO[Any, AwsError, VersionQualifier] =
      AwsError.unwrapOptionField("versionQualifier", versionQualifier)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.robomaker.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.ListRobotApplicationsRequest
  ) extends zio.aws.robomaker.model.ListRobotApplicationsRequest.ReadOnly {
    override val versionQualifier: Option[VersionQualifier] = scala
      .Option(impl.versionQualifier())
      .map(value => zio.aws.robomaker.model.primitives.VersionQualifier(value))
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.robomaker.model.primitives.PaginationToken(value))
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.robomaker.model.primitives.MaxResults(value))
    override val filters
        : Option[List[zio.aws.robomaker.model.Filter.ReadOnly]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.robomaker.model.Filter.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.ListRobotApplicationsRequest
  ): zio.aws.robomaker.model.ListRobotApplicationsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-robomaker_3-5.17.188.1-sources.jar: zio/aws/robomaker/model/ListRobotApplicationsRequest.scala <==
package zio.aws.robomaker.model
import zio.aws.robomaker.model.primitives.{
  MaxResults,
  PaginationToken,
  VersionQualifier
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListRobotApplicationsRequest(
    versionQualifier: Optional[VersionQualifier] = Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.robomaker.model.Filter]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.ListRobotApplicationsRequest = {
    import ListRobotApplicationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.ListRobotApplicationsRequest
      .builder()
      .optionallyWith(
        versionQualifier.map(value =>
          VersionQualifier.unwrap(value): java.lang.String
        )
      )(_.versionQualifier)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .build()
  }
  def asReadOnly
      : zio.aws.robomaker.model.ListRobotApplicationsRequest.ReadOnly =
    zio.aws.robomaker.model.ListRobotApplicationsRequest.wrap(buildAwsValue())
}
object ListRobotApplicationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.robomaker.model.ListRobotApplicationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.ListRobotApplicationsRequest =
      zio.aws.robomaker.model.ListRobotApplicationsRequest(
        versionQualifier.map(value => value),
        nextToken.map(value => value),
        maxResults.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def versionQualifier: Optional[VersionQualifier]
    def nextToken: Optional[PaginationToken]
    def maxResults: Optional[MaxResults]
    def filters: Optional[List[zio.aws.robomaker.model.Filter.ReadOnly]]
    def getVersionQualifier: ZIO[Any, AwsError, VersionQualifier] =
      AwsError.unwrapOptionField("versionQualifier", versionQualifier)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.robomaker.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.ListRobotApplicationsRequest
  ) extends zio.aws.robomaker.model.ListRobotApplicationsRequest.ReadOnly {
    override val versionQualifier: Optional[VersionQualifier] =
      zio.aws.core.internal
        .optionalFromNullable(impl.versionQualifier())
        .map(value =>
          zio.aws.robomaker.model.primitives.VersionQualifier(value)
        )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.robomaker.model.primitives.PaginationToken(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.robomaker.model.primitives.MaxResults(value))
    override val filters
        : Optional[List[zio.aws.robomaker.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.robomaker.model.Filter.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.ListRobotApplicationsRequest
  ): zio.aws.robomaker.model.ListRobotApplicationsRequest.ReadOnly =
    new Wrapper(impl)
}
